{% load i18n social_share %}{% get_current_language as LANGUAGE_CODE %}<div class="linkedin-this {{link_class}}">
  <script src="https://platform.linkedin.com/in.js" type="text/javascript">lang: {{ LANGUAGE_CODE|linkedin_locale }}</script>
  <script type="IN/Share" data-url="{{ linkedin_url }}"></script>
</div>
